package view

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.WindowInsets
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.systemBars
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.layout.windowInsetsPadding
import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.foundation.lazy.grid.rememberLazyGridState
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import model.TagType


@Composable
fun BookShelf(
    onClick: (String) -> Unit,
    isLarge: Boolean,
    tags: Map<String, TagType>
) {

    Box(
        modifier = Modifier
    ) {
        Column(
            modifier = Modifier
                .padding(top = 10.dp)
                .align(Alignment.Center),
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Center,
        ) {

            Text(text = "What Do You Want To Cook Today?", textAlign = TextAlign.Center)

            Button(onClick = { onClick("") }) {
                Text("Anything")
            }

            for (type in tags.values.toSet().toList().sorted()) // get all unique tag types
            {
                var list =
                    tags.filterValues { it == type }.keys.toList() // get list of all keys that have this value
                list = list.sorted()

                Text("Cook By ".plus(type.name))

                val listState = rememberLazyGridState()

                LazyVerticalGrid(
                    columns = GridCells.Fixed(if (isLarge) 4 else 2),
                    state = listState,
                    modifier = Modifier.width(if(isLarge) 600.dp else 350.dp)
                ) {
                    items(list.size) { item ->
                        val tag = list[item]
                        Button(onClick = { onClick(tag) },
                            modifier = Modifier.width(30.dp)) {
                            Text(tag)
                        }
                    }
                }
            }

        }
    }
}