package view

import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import model.Recipe
import model.americanList
import model.chineseList
import model.exampleList
import model.indianList
import model.italianList
import model.koreanList
import model.mexicanList
import model.seaList

fun List<String>.containsPartial(text:String) : Boolean {
    return  this.any {it.lowercase().contains(text.lowercase())}
}

@Composable
fun getFilteredRecipeList(
    tags : List<String>,
    search : String,
    lockTag : String,
) : List<Recipe> {
    val items = getRecipeList()

    var recipes = items.filter { it.tags.keys.containsAll(tags) }

    recipes = recipes.filter {
        it.title.lowercase().contains(search.lowercase()) || it.ingredients.containsPartial(search)
    }

    if (lockTag != "")
    {
        recipes = recipes.filter { it.tags.contains(lockTag)}
    }

    recipes = recipes.sortedBy { it.title }

    return recipes
}

@Composable
fun getRecipeList() : List<Recipe> {
    //val exampleRecipes by remember { mutableStateOf(exampleList) }
    val americanRecipes by remember { mutableStateOf(americanList) }
    val italianRecipes by remember { mutableStateOf(italianList) }
    val mexicanRecipes by remember { mutableStateOf(mexicanList) }
    val chineseRecipes by remember { mutableStateOf(chineseList) }
    val koreanRecipes by remember { mutableStateOf(koreanList) }
    val indianRecipes by remember { mutableStateOf(indianList) }
    val seaRecipes by remember { mutableStateOf(seaList) }
    val items : MutableList<Recipe> = mutableListOf()


    //items.addAll(exampleRecipes)
    items.addAll(americanRecipes)
    items.addAll(italianRecipes)
    items.addAll(mexicanRecipes)
    items.addAll(chineseRecipes)
    items.addAll(koreanRecipes)
    items.addAll(indianRecipes)
    items.addAll(seaRecipes)

    return items
}